# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto',
  package='github.com.metaprov.modelaapi.services.dataapp.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/dataapp/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto\x12\x31github.com.metaprov.modelaapi.services.dataapp.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xc9\x01\n\x13ListDataAppsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\x14ListDataAppsResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataAppList\"\x17\n\x15\x43reateDataAppResponse\"h\n\x14\x43reateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"h\n\x14UpdateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x17\n\x15UpdateDataAppResponse\"4\n\x11GetDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x12GetDataAppResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteDataAppResponse\"6\n\x13PauseDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14PauseDataAppResponse\"7\n\x14ResumeDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15ResumeDataAppResponse\"e\n\x11RunDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x14\n\x12RunDataAppResponse2\xfd\n\n\x0e\x44\x61taAppService\x12\xb8\x01\n\x0cListDataApps\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/webeequests\x12\xbe\x01\n\rCreateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webeequests:\x01*\x12\xb9\x01\n\nGetDataApp\x12\x44.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/webeequests/{name}\x12\xd9\x01\n\rUpdateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/webeequests/{webeequest.metadata.name}:\x01*\x12\xc2\x01\n\rDeleteDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/webeequests/{name}\x12\xc5\x01\n\x0cPauseDataApp\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/v1/webeequests/{name}:pause\x12\xc9\x01\n\rResumeDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/v1/webeequests/{name}:resumeB3Z1github.com/metaprov/modelaapi/services/dataapp/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTDATAAPPSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=425,
)

_LISTDATAAPPSREQUEST = _descriptor.Descriptor(
  name='ListDataAppsRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATAAPPSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=425,
)


_LISTDATAAPPSRESPONSE = _descriptor.Descriptor(
  name='ListDataAppsResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=536,
)


_CREATEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='CreateDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=561,
)


_CREATEDATAAPPREQUEST = _descriptor.Descriptor(
  name='CreateDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=667,
)


_UPDATEDATAAPPREQUEST = _descriptor.Descriptor(
  name='UpdateDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=773,
)


_UPDATEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='UpdateDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=798,
)


_GETDATAAPPREQUEST = _descriptor.Descriptor(
  name='GetDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=852,
)


_GETDATAAPPRESPONSE = _descriptor.Descriptor(
  name='GetDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=970,
)


_DELETEDATAAPPREQUEST = _descriptor.Descriptor(
  name='DeleteDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1027,
)


_DELETEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='DeleteDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1029,
  serialized_end=1052,
)


_PAUSEDATAAPPREQUEST = _descriptor.Descriptor(
  name='PauseDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1108,
)


_PAUSEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='PauseDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1132,
)


_RESUMEDATAAPPREQUEST = _descriptor.Descriptor(
  name='ResumeDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1189,
)


_RESUMEDATAAPPRESPONSE = _descriptor.Descriptor(
  name='ResumeDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1191,
  serialized_end=1214,
)


_RUNDATAAPPREQUEST = _descriptor.Descriptor(
  name='RunDataAppRequest',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1216,
  serialized_end=1317,
)


_RUNDATAAPPRESPONSE = _descriptor.Descriptor(
  name='RunDataAppResponse',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1339,
)

_LISTDATAAPPSREQUEST_LABELSENTRY.containing_type = _LISTDATAAPPSREQUEST
_LISTDATAAPPSREQUEST.fields_by_name['labels'].message_type = _LISTDATAAPPSREQUEST_LABELSENTRY
_LISTDATAAPPSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPPLIST
_CREATEDATAAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
_UPDATEDATAAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
_GETDATAAPPRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
_RUNDATAAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._DATAAPP
DESCRIPTOR.message_types_by_name['ListDataAppsRequest'] = _LISTDATAAPPSREQUEST
DESCRIPTOR.message_types_by_name['ListDataAppsResponse'] = _LISTDATAAPPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataAppResponse'] = _CREATEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataAppRequest'] = _CREATEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataAppRequest'] = _UPDATEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataAppResponse'] = _UPDATEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['GetDataAppRequest'] = _GETDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['GetDataAppResponse'] = _GETDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDataAppRequest'] = _DELETEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataAppResponse'] = _DELETEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['PauseDataAppRequest'] = _PAUSEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['PauseDataAppResponse'] = _PAUSEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['ResumeDataAppRequest'] = _RESUMEDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['ResumeDataAppResponse'] = _RESUMEDATAAPPRESPONSE
DESCRIPTOR.message_types_by_name['RunDataAppRequest'] = _RUNDATAAPPREQUEST
DESCRIPTOR.message_types_by_name['RunDataAppResponse'] = _RUNDATAAPPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDataAppsRequest = _reflection.GeneratedProtocolMessageType('ListDataAppsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAAPPSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAAPPSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest)
  })
_sym_db.RegisterMessage(ListDataAppsRequest)
_sym_db.RegisterMessage(ListDataAppsRequest.LabelsEntry)

ListDataAppsResponse = _reflection.GeneratedProtocolMessageType('ListDataAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse)
  })
_sym_db.RegisterMessage(ListDataAppsResponse)

CreateDataAppResponse = _reflection.GeneratedProtocolMessageType('CreateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse)
  })
_sym_db.RegisterMessage(CreateDataAppResponse)

CreateDataAppRequest = _reflection.GeneratedProtocolMessageType('CreateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest)
  })
_sym_db.RegisterMessage(CreateDataAppRequest)

UpdateDataAppRequest = _reflection.GeneratedProtocolMessageType('UpdateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest)
  })
_sym_db.RegisterMessage(UpdateDataAppRequest)

UpdateDataAppResponse = _reflection.GeneratedProtocolMessageType('UpdateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse)
  })
_sym_db.RegisterMessage(UpdateDataAppResponse)

GetDataAppRequest = _reflection.GeneratedProtocolMessageType('GetDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest)
  })
_sym_db.RegisterMessage(GetDataAppRequest)

GetDataAppResponse = _reflection.GeneratedProtocolMessageType('GetDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse)
  })
_sym_db.RegisterMessage(GetDataAppResponse)

DeleteDataAppRequest = _reflection.GeneratedProtocolMessageType('DeleteDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest)
  })
_sym_db.RegisterMessage(DeleteDataAppRequest)

DeleteDataAppResponse = _reflection.GeneratedProtocolMessageType('DeleteDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse)
  })
_sym_db.RegisterMessage(DeleteDataAppResponse)

PauseDataAppRequest = _reflection.GeneratedProtocolMessageType('PauseDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest)
  })
_sym_db.RegisterMessage(PauseDataAppRequest)

PauseDataAppResponse = _reflection.GeneratedProtocolMessageType('PauseDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse)
  })
_sym_db.RegisterMessage(PauseDataAppResponse)

ResumeDataAppRequest = _reflection.GeneratedProtocolMessageType('ResumeDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest)
  })
_sym_db.RegisterMessage(ResumeDataAppRequest)

ResumeDataAppResponse = _reflection.GeneratedProtocolMessageType('ResumeDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse)
  })
_sym_db.RegisterMessage(ResumeDataAppResponse)

RunDataAppRequest = _reflection.GeneratedProtocolMessageType('RunDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest)
  })
_sym_db.RegisterMessage(RunDataAppRequest)

RunDataAppResponse = _reflection.GeneratedProtocolMessageType('RunDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse)
  })
_sym_db.RegisterMessage(RunDataAppResponse)


DESCRIPTOR._options = None
_LISTDATAAPPSREQUEST_LABELSENTRY._options = None

_DATAAPPSERVICE = _descriptor.ServiceDescriptor(
  name='DataAppService',
  full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1342,
  serialized_end=2747,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataApps',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.ListDataApps',
    index=0,
    containing_service=None,
    input_type=_LISTDATAAPPSREQUEST,
    output_type=_LISTDATAAPPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/webeequests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.CreateDataApp',
    index=1,
    containing_service=None,
    input_type=_CREATEDATAAPPREQUEST,
    output_type=_CREATEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/webeequests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.GetDataApp',
    index=2,
    containing_service=None,
    input_type=_GETDATAAPPREQUEST,
    output_type=_GETDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.UpdateDataApp',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATAAPPREQUEST,
    output_type=_UPDATEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/webeequests/{webeequest.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.DeleteDataApp',
    index=4,
    containing_service=None,
    input_type=_DELETEDATAAPPREQUEST,
    output_type=_DELETEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.PauseDataApp',
    index=5,
    containing_service=None,
    input_type=_PAUSEDATAAPPREQUEST,
    output_type=_PAUSEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\034/v1/webeequests/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeDataApp',
    full_name='github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService.ResumeDataApp',
    index=6,
    containing_service=None,
    input_type=_RESUMEDATAAPPREQUEST,
    output_type=_RESUMEDATAAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\"\035/v1/webeequests/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAAPPSERVICE)

DESCRIPTOR.services_by_name['DataAppService'] = _DATAAPPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/meeting/v1/meeting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/meeting/v1/meeting.proto',
  package='github.com.metaprov.modelaapi.services.meeting.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/meeting/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/meeting/v1/meeting.proto\x12\x31github.com.metaprov.modelaapi.services.meeting.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbb\x01\n\x13ListMeetingsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x14ListMeetingsResponse\x12P\n\x05items\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingList\"\x11\n\x0fMeetingResponse\"u\n\x14\x43reateMeetingRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\x12\x10\n\x08password\x18\x02 \x01(\t\"\x17\n\x15\x43reateMeetingResponse\"c\n\x14UpdateMeetingRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"\x17\n\x15UpdateMeetingResponse\"4\n\x11GetMeetingRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x12GetMeetingResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1bGetMeetingNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1cGetMeetingNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"7\n\x14\x44\x65leteMeetingRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteMeetingResponse\"\x17\n\x15MeetingCreateResponse\":\n\x17MeetingGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"%\n\x14MeetingLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t2\x9d\x08\n\x0eMeetingService\x12\xb5\x01\n\x0cListMeetings\x12\x46.github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest\x1aG.github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/meetings\x12\xc1\x01\n\rCreateMeeting\x12G.github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest\x1aH.github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/meetings:\x07meeting\x12\xc2\x01\n\nGetMeeting\x12\x44.github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest\x1a\x45.github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{namespace}/meetings/{name}\x12\xf7\x01\n\rUpdateMeeting\x12G.github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingRequest\x1aH.github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingResponse\"S\x82\xd3\xe4\x93\x02M\x1a\x42/v1/{meeting.metadata.namespace}/meetings//{meeting.metadata.name}:\x07meeting\x12\xcf\x01\n\rDeleteMeeting\x12G.github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest\x1aH.github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingResponse\"+\x82\xd3\xe4\x93\x02%*#/api/{namespace}/v1/meetings/{name}B3Z1github.com/metaprov/modelaapi/services/meeting/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTMEETINGSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=469,
)

_LISTMEETINGSREQUEST = _descriptor.Descriptor(
  name='ListMeetingsRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMEETINGSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=469,
)


_LISTMEETINGSRESPONSE = _descriptor.Descriptor(
  name='ListMeetingsResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=575,
)


_MEETINGRESPONSE = _descriptor.Descriptor(
  name='MeetingResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=594,
)


_CREATEMEETINGREQUEST = _descriptor.Descriptor(
  name='CreateMeetingRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=713,
)


_CREATEMEETINGRESPONSE = _descriptor.Descriptor(
  name='CreateMeetingResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=738,
)


_UPDATEMEETINGREQUEST = _descriptor.Descriptor(
  name='UpdateMeetingRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=839,
)


_UPDATEMEETINGRESPONSE = _descriptor.Descriptor(
  name='UpdateMeetingResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=864,
)


_GETMEETINGREQUEST = _descriptor.Descriptor(
  name='GetMeetingRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=918,
)


_GETMEETINGRESPONSE = _descriptor.Descriptor(
  name='GetMeetingResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=920,
  serialized_end=1031,
)


_GETMEETINGNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetMeetingNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1033,
  serialized_end=1095,
)


_GETMEETINGNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetMeetingNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1212,
)


_DELETEMEETINGREQUEST = _descriptor.Descriptor(
  name='DeleteMeetingRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1269,
)


_DELETEMEETINGRESPONSE = _descriptor.Descriptor(
  name='DeleteMeetingResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1271,
  serialized_end=1294,
)


_MEETINGCREATERESPONSE = _descriptor.Descriptor(
  name='MeetingCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1296,
  serialized_end=1319,
)


_MEETINGGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='MeetingGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1321,
  serialized_end=1379,
)


_MEETINGLOGOUTREQUEST = _descriptor.Descriptor(
  name='MeetingLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1418,
)

_LISTMEETINGSREQUEST_LABELSENTRY.containing_type = _LISTMEETINGSREQUEST
_LISTMEETINGSREQUEST.fields_by_name['labels'].message_type = _LISTMEETINGSREQUEST_LABELSENTRY
_LISTMEETINGSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._MEETINGLIST
_CREATEMEETINGREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._MEETING
_UPDATEMEETINGREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._MEETING
_GETMEETINGRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._MEETING
_GETMEETINGNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListMeetingsRequest'] = _LISTMEETINGSREQUEST
DESCRIPTOR.message_types_by_name['ListMeetingsResponse'] = _LISTMEETINGSRESPONSE
DESCRIPTOR.message_types_by_name['MeetingResponse'] = _MEETINGRESPONSE
DESCRIPTOR.message_types_by_name['CreateMeetingRequest'] = _CREATEMEETINGREQUEST
DESCRIPTOR.message_types_by_name['CreateMeetingResponse'] = _CREATEMEETINGRESPONSE
DESCRIPTOR.message_types_by_name['UpdateMeetingRequest'] = _UPDATEMEETINGREQUEST
DESCRIPTOR.message_types_by_name['UpdateMeetingResponse'] = _UPDATEMEETINGRESPONSE
DESCRIPTOR.message_types_by_name['GetMeetingRequest'] = _GETMEETINGREQUEST
DESCRIPTOR.message_types_by_name['GetMeetingResponse'] = _GETMEETINGRESPONSE
DESCRIPTOR.message_types_by_name['GetMeetingNamespacesRequest'] = _GETMEETINGNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetMeetingNamespacesResponse'] = _GETMEETINGNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteMeetingRequest'] = _DELETEMEETINGREQUEST
DESCRIPTOR.message_types_by_name['DeleteMeetingResponse'] = _DELETEMEETINGRESPONSE
DESCRIPTOR.message_types_by_name['MeetingCreateResponse'] = _MEETINGCREATERESPONSE
DESCRIPTOR.message_types_by_name['MeetingGetByNameRequest'] = _MEETINGGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['MeetingLogoutRequest'] = _MEETINGLOGOUTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListMeetingsRequest = _reflection.GeneratedProtocolMessageType('ListMeetingsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEETINGSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMEETINGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest)
  })
_sym_db.RegisterMessage(ListMeetingsRequest)
_sym_db.RegisterMessage(ListMeetingsRequest.LabelsEntry)

ListMeetingsResponse = _reflection.GeneratedProtocolMessageType('ListMeetingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEETINGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsResponse)
  })
_sym_db.RegisterMessage(ListMeetingsResponse)

MeetingResponse = _reflection.GeneratedProtocolMessageType('MeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.MeetingResponse)
  })
_sym_db.RegisterMessage(MeetingResponse)

CreateMeetingRequest = _reflection.GeneratedProtocolMessageType('CreateMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest)
  })
_sym_db.RegisterMessage(CreateMeetingRequest)

CreateMeetingResponse = _reflection.GeneratedProtocolMessageType('CreateMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingResponse)
  })
_sym_db.RegisterMessage(CreateMeetingResponse)

UpdateMeetingRequest = _reflection.GeneratedProtocolMessageType('UpdateMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingRequest)
  })
_sym_db.RegisterMessage(UpdateMeetingRequest)

UpdateMeetingResponse = _reflection.GeneratedProtocolMessageType('UpdateMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingResponse)
  })
_sym_db.RegisterMessage(UpdateMeetingResponse)

GetMeetingRequest = _reflection.GeneratedProtocolMessageType('GetMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest)
  })
_sym_db.RegisterMessage(GetMeetingRequest)

GetMeetingResponse = _reflection.GeneratedProtocolMessageType('GetMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse)
  })
_sym_db.RegisterMessage(GetMeetingResponse)

GetMeetingNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetMeetingNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesRequest)
  })
_sym_db.RegisterMessage(GetMeetingNamespacesRequest)

GetMeetingNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetMeetingNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingNamespacesResponse)
  })
_sym_db.RegisterMessage(GetMeetingNamespacesResponse)

DeleteMeetingRequest = _reflection.GeneratedProtocolMessageType('DeleteMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest)
  })
_sym_db.RegisterMessage(DeleteMeetingRequest)

DeleteMeetingResponse = _reflection.GeneratedProtocolMessageType('DeleteMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingResponse)
  })
_sym_db.RegisterMessage(DeleteMeetingResponse)

MeetingCreateResponse = _reflection.GeneratedProtocolMessageType('MeetingCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.MeetingCreateResponse)
  })
_sym_db.RegisterMessage(MeetingCreateResponse)

MeetingGetByNameRequest = _reflection.GeneratedProtocolMessageType('MeetingGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.MeetingGetByNameRequest)
  })
_sym_db.RegisterMessage(MeetingGetByNameRequest)

MeetingLogoutRequest = _reflection.GeneratedProtocolMessageType('MeetingLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.MeetingLogoutRequest)
  })
_sym_db.RegisterMessage(MeetingLogoutRequest)


DESCRIPTOR._options = None
_LISTMEETINGSREQUEST_LABELSENTRY._options = None

_MEETINGSERVICE = _descriptor.ServiceDescriptor(
  name='MeetingService',
  full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1421,
  serialized_end=2474,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListMeetings',
    full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingService.ListMeetings',
    index=0,
    containing_service=None,
    input_type=_LISTMEETINGSREQUEST,
    output_type=_LISTMEETINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/meetings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateMeeting',
    full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingService.CreateMeeting',
    index=1,
    containing_service=None,
    input_type=_CREATEMEETINGREQUEST,
    output_type=_CREATEMEETINGRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\014/v1/meetings:\007meeting',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMeeting',
    full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingService.GetMeeting',
    index=2,
    containing_service=None,
    input_type=_GETMEETINGREQUEST,
    output_type=_GETMEETINGRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/v1/{namespace}/meetings/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMeeting',
    full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingService.UpdateMeeting',
    index=3,
    containing_service=None,
    input_type=_UPDATEMEETINGREQUEST,
    output_type=_UPDATEMEETINGRESPONSE,
    serialized_options=b'\202\323\344\223\002M\032B/v1/{meeting.metadata.namespace}/meetings//{meeting.metadata.name}:\007meeting',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMeeting',
    full_name='github.com.metaprov.modelaapi.services.meeting.v1.MeetingService.DeleteMeeting',
    index=4,
    containing_service=None,
    input_type=_DELETEMEETINGREQUEST,
    output_type=_DELETEMEETINGRESPONSE,
    serialized_options=b'\202\323\344\223\002%*#/api/{namespace}/v1/meetings/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MEETINGSERVICE)

DESCRIPTOR.services_by_name['MeetingService'] = _MEETINGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/sqlquery/v1/sqlquery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/sqlquery/v1/sqlquery.proto',
  package='github.com.metaprov.modelaapi.services.sqlquery.v1',
  syntax='proto3',
  serialized_options=b'Z2github.com/metaprov/modelaapi/services/sqlquery/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAgithub.com/metaprov/modelaapi/services/sqlquery/v1/sqlquery.proto\x12\x32github.com.metaprov.modelaapi.services.sqlquery.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xcc\x01\n\x14ListSqlQuerysRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x64\n\x06labels\x18\x03 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x15ListSqlQuerysResponse\x12Q\n\x05items\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryList\"\x18\n\x16\x43reateSqlQueryResponse\"e\n\x15\x43reateSqlQueryRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"e\n\x15UpdateSqlQueryRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x18\n\x16UpdateSqlQueryResponse\"5\n\x12GetSqlQueryRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"q\n\x13GetSqlQueryResponse\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteSqlQueryRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSqlQueryResponse\"b\n\x12RunSqlQueryRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x15\n\x13RunSqlQueryResponse2\xbe\t\n\x0fSqlQueryService\x12\xbc\x01\n\rListSqlQuerys\x12H.github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest\x1aI.github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/sqlqueries\x12\xc1\x01\n\x0e\x43reateSqlQuery\x12I.github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryRequest\x1aJ.github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/sqlquerys:\x01*\x12\xbd\x01\n\x0bGetSqlQuery\x12\x46.github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest\x1aG.github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/sqlqueries/{name}\x12\xda\x01\n\x0eUpdateSqlQuery\x12I.github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryRequest\x1aJ.github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryResponse\"1\x82\xd3\xe4\x93\x02+\x1a&/v1/sqlquerys/{sqlquery.metadata.name}:\x01*\x12\xc6\x01\n\x0e\x44\x65leteSqlQuery\x12I.github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest\x1aJ.github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryResponse\"\x1d\x82\xd3\xe4\x93\x02\x17*\x15/v1/sqlqueries/{name}\x12\xc1\x01\n\x0bRunSqlQuery\x12\x46.github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryRequest\x1aG.github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/v1/sqlqueries/{name}:runB4Z2github.com/metaprov/modelaapi/services/sqlquery/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTSQLQUERYSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=381,
  serialized_end=426,
)

_LISTSQLQUERYSREQUEST = _descriptor.Descriptor(
  name='ListSqlQuerysRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSQLQUERYSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=426,
)


_LISTSQLQUERYSRESPONSE = _descriptor.Descriptor(
  name='ListSqlQuerysResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=534,
)


_CREATESQLQUERYRESPONSE = _descriptor.Descriptor(
  name='CreateSqlQueryResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=560,
)


_CREATESQLQUERYREQUEST = _descriptor.Descriptor(
  name='CreateSqlQueryRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=663,
)


_UPDATESQLQUERYREQUEST = _descriptor.Descriptor(
  name='UpdateSqlQueryRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=766,
)


_UPDATESQLQUERYRESPONSE = _descriptor.Descriptor(
  name='UpdateSqlQueryResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=768,
  serialized_end=792,
)


_GETSQLQUERYREQUEST = _descriptor.Descriptor(
  name='GetSqlQueryRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=847,
)


_GETSQLQUERYRESPONSE = _descriptor.Descriptor(
  name='GetSqlQueryResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=962,
)


_DELETESQLQUERYREQUEST = _descriptor.Descriptor(
  name='DeleteSqlQueryRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1020,
)


_DELETESQLQUERYRESPONSE = _descriptor.Descriptor(
  name='DeleteSqlQueryResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1046,
)


_RUNSQLQUERYREQUEST = _descriptor.Descriptor(
  name='RunSqlQueryRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1146,
)


_RUNSQLQUERYRESPONSE = _descriptor.Descriptor(
  name='RunSqlQueryResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1169,
)

_LISTSQLQUERYSREQUEST_LABELSENTRY.containing_type = _LISTSQLQUERYSREQUEST
_LISTSQLQUERYSREQUEST.fields_by_name['labels'].message_type = _LISTSQLQUERYSREQUEST_LABELSENTRY
_LISTSQLQUERYSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYLIST
_CREATESQLQUERYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERY
_UPDATESQLQUERYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERY
_GETSQLQUERYRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERY
_RUNSQLQUERYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERY
DESCRIPTOR.message_types_by_name['ListSqlQuerysRequest'] = _LISTSQLQUERYSREQUEST
DESCRIPTOR.message_types_by_name['ListSqlQuerysResponse'] = _LISTSQLQUERYSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSqlQueryResponse'] = _CREATESQLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['CreateSqlQueryRequest'] = _CREATESQLQUERYREQUEST
DESCRIPTOR.message_types_by_name['UpdateSqlQueryRequest'] = _UPDATESQLQUERYREQUEST
DESCRIPTOR.message_types_by_name['UpdateSqlQueryResponse'] = _UPDATESQLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['GetSqlQueryRequest'] = _GETSQLQUERYREQUEST
DESCRIPTOR.message_types_by_name['GetSqlQueryResponse'] = _GETSQLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSqlQueryRequest'] = _DELETESQLQUERYREQUEST
DESCRIPTOR.message_types_by_name['DeleteSqlQueryResponse'] = _DELETESQLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['RunSqlQueryRequest'] = _RUNSQLQUERYREQUEST
DESCRIPTOR.message_types_by_name['RunSqlQueryResponse'] = _RUNSQLQUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListSqlQuerysRequest = _reflection.GeneratedProtocolMessageType('ListSqlQuerysRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSQLQUERYSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSQLQUERYSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest)
  })
_sym_db.RegisterMessage(ListSqlQuerysRequest)
_sym_db.RegisterMessage(ListSqlQuerysRequest.LabelsEntry)

ListSqlQuerysResponse = _reflection.GeneratedProtocolMessageType('ListSqlQuerysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysResponse)
  })
_sym_db.RegisterMessage(ListSqlQuerysResponse)

CreateSqlQueryResponse = _reflection.GeneratedProtocolMessageType('CreateSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryResponse)
  })
_sym_db.RegisterMessage(CreateSqlQueryResponse)

CreateSqlQueryRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRequest)

UpdateSqlQueryRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRequest)

UpdateSqlQueryResponse = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryResponse)
  })
_sym_db.RegisterMessage(UpdateSqlQueryResponse)

GetSqlQueryRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRequest)

GetSqlQueryResponse = _reflection.GeneratedProtocolMessageType('GetSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse)
  })
_sym_db.RegisterMessage(GetSqlQueryResponse)

DeleteSqlQueryRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRequest)

DeleteSqlQueryResponse = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryResponse)
  })
_sym_db.RegisterMessage(DeleteSqlQueryResponse)

RunSqlQueryRequest = _reflection.GeneratedProtocolMessageType('RunSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryRequest)
  })
_sym_db.RegisterMessage(RunSqlQueryRequest)

RunSqlQueryResponse = _reflection.GeneratedProtocolMessageType('RunSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryResponse)
  })
_sym_db.RegisterMessage(RunSqlQueryResponse)


DESCRIPTOR._options = None
_LISTSQLQUERYSREQUEST_LABELSENTRY._options = None

_SQLQUERYSERVICE = _descriptor.ServiceDescriptor(
  name='SqlQueryService',
  full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1172,
  serialized_end=2386,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListSqlQuerys',
    full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService.ListSqlQuerys',
    index=0,
    containing_service=None,
    input_type=_LISTSQLQUERYSREQUEST,
    output_type=_LISTSQLQUERYSRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1/sqlqueries',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSqlQuery',
    full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService.CreateSqlQuery',
    index=1,
    containing_service=None,
    input_type=_CREATESQLQUERYREQUEST,
    output_type=_CREATESQLQUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\"\r/v1/sqlquerys:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSqlQuery',
    full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService.GetSqlQuery',
    index=2,
    containing_service=None,
    input_type=_GETSQLQUERYREQUEST,
    output_type=_GETSQLQUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/sqlqueries/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSqlQuery',
    full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService.UpdateSqlQuery',
    index=3,
    containing_service=None,
    input_type=_UPDATESQLQUERYREQUEST,
    output_type=_UPDATESQLQUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002+\032&/v1/sqlquerys/{sqlquery.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSqlQuery',
    full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService.DeleteSqlQuery',
    index=4,
    containing_service=None,
    input_type=_DELETESQLQUERYREQUEST,
    output_type=_DELETESQLQUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\027*\025/v1/sqlqueries/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunSqlQuery',
    full_name='github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService.RunSqlQuery',
    index=5,
    containing_service=None,
    input_type=_RUNSQLQUERYREQUEST,
    output_type=_RUNSQLQUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\031/v1/sqlqueries/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SQLQUERYSERVICE)

DESCRIPTOR.services_by_name['SqlQueryService'] = _SQLQUERYSERVICE

# @@protoc_insertion_point(module_scope)
